@@ -133,13 +133,14 @@ MainWindow::MainWindow(
   {
     bool uilat = settings.value("UseIndicatorLEDAsTorch").toBool();
 
+    ui->whiteButton->setChecked(!uilat);
     ui->redButton->setChecked(uilat);
 
     useIndicatorLED(uilat);
   }
   else
   {
-    ui->redButton->setChecked(false);
+    ui->whiteButton->setChecked(true);
   }
 }
 
@@ -152,7 +153,7 @@ MainWindow::~MainWindow()
     settings.setValue("BrightLightWarningSeen", true);
   }
 
-  settings.setValue("UseIndicatorLEDAsTorch", ui->redButton->isEnabled());
+  settings.setValue("UseIndicatorLEDAsTorch", ui->redButton->isChecked());
 
   if (aboutForm) delete aboutForm;
   if (strobeForm) delete strobeForm;
